IF OBJECT_ID('[PackagesSlim_Combined]') IS NOT NULL DROP VIEW [PackagesSlim_Combined]
GO

CREATE VIEW [PackagesSlim_Combined]
AS
	SELECT NGP.[Feed_Id],
		   [Package_Name] = CAST(NGP.[Package_Id] AS VARCHAR(255)),
		   [Group_Name] = CAST(NULL AS VARCHAR(200)),
	       [FeedType_Name] = F.[FeedType_Name],
		   [Version_Text] = NGPV.[Version_Text]
	  FROM [NuGetPackagesV2] NGP
	       INNER JOIN [Feeds] F
		           ON F.[Feed_Id] = NGP.[Feed_Id]
		   INNER JOIN [NuGetPackageVersionsV2] NGPV
		           ON NGPV.[NuGetPackageV2_Id] = NGP.[NuGetPackageV2_Id]

UNION ALL

	SELECT NP.[Feed_Id],
	       [Package_Name] = CAST(NP.[Package_Name] AS VARCHAR(255)),
		   [Group_Name] = CAST(NULLIF(NP.[Scope_Name], '') AS VARCHAR(200)),
		   [FeedType_Name] = 'npm',
		   [Version_Text] = NPV.[Version_Text]
	  FROM [NpmPackages] NP
	       INNER JOIN [NpmPackageVersions] NPV
		           ON NPV.[Package_Id] = NP.[Package_Id]

UNION ALL

	SELECT BP.[Feed_Id],
	       [Package_Name] = CAST(BP.[Package_Name] AS VARCHAR(255)),
		   [Group_Name] = CAST(NULL AS VARCHAR(200)),
		   [FeedType_Name] = 'Bower',
		   [Version_Text] = CAST(NULL AS VARCHAR(200))
	  FROM [BowerPackages] BP

UNION ALL

	SELECT MA.[Feed_Id],
		   [Package_Name] = CAST(MA.[ArtifactId_Text] AS VARCHAR(255)),
	       [Group_Name] = CAST(MA.[GroupId_Text] AS VARCHAR(200)),
		   [FeedType_Name] = 'Maven',
		   [Version_Text] = CAST(MAF.[Version_Text] AS VARCHAR(200))
	  FROM [MavenArtifacts] MA
	       INNER JOIN (SELECT [MavenArtifact_Id],
		                      [Version_Text]
		                 FROM [MavenArtifactFiles]
		                 GROUP BY [MavenArtifact_Id], [Version_Text]) MAF
		           ON MAF.[MavenArtifact_Id] = MA.[MavenArtifact_Id]

UNION ALL

	SELECT DP.[Feed_Id],
		   [Package_Name] = DP.[Package_Name] + ':' + DP.[Architecture_Name],
	       [Group_Name] = DP.[Component_Name],
		   [FeedType_Name] = 'Debian',
		   DP.[Version_Text]
	  FROM [DebianPackages] DP

UNION ALL

	SELECT HC.[Feed_Id],
	       [Package_Name] = HC.[Chart_Name],
	       [Group_Name] = NULL,
	       [FeedType_Name] = 'Helm',
	       HC.[Version_Text]
	  FROM [HelmCharts] HC

UNION ALL

	SELECT RP.[Feed_Id],
	       RP.[Package_Name] COLLATE Latin1_General_CS_AS,
		   [Group_Name] = RP.[Architecture_Name] COLLATE Latin1_General_CS_AS,
		   [FeedType_Name] = 'RPM',
		   RPV.[FullVersion_Text]
	  FROM [RpmPackages] RP
	       INNER JOIN [RpmPackageVersions] RPV
		           ON RPV.[RpmPackage_Id] = RP.[RpmPackage_Id]
				   

UNION ALL

	SELECT Py.[Feed_Id],
	       Py.[Package_Name],
		   [Group_Name] = NULL,
		   [FeedType_Name] = 'Pypi',
		   py.[Version_Text]
	  FROM [PypiPackages] Py

	  UNION ALL

	SELECT RG.[Feed_Id],
	       [Package_Name] = CAST(RG.[Gem_Name] AS VARCHAR(255)),
		   [Group_Name] = NULL,
		   [FeedType_Name] = 'RubyGems',
		   [Version_Text] = RGV.[Version_Text]
	  FROM [RubyGems] RG
	       INNER JOIN [RubyGemVersions] RGV
		           ON RG.[Gem_Id] = RGV.[Gem_Id]
