EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'PackageDependents_AddRepackageRecords',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'NULL',
    /* Description_Text        */ 'Inserts records maintain usage data after a promotion or repack.'
GO

IF OBJECT_ID('[PackageDependents_AddRepackageRecords]') IS NOT NULL DROP PROCEDURE [PackageDependents_AddRepackageRecords]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [PackageDependents_AddRepackageRecords]
(
    @Dependent_Feed_Id INT,
    @Dependent_Group_Name VARCHAR(200),
    @Dependent_Package_Name VARCHAR(200),
    @Dependent_Version_Text VARCHAR(100),
    @New_Dependent_Feed_Id INT,
    @New_Dependent_Version_Text VARCHAR(100),
    @Notes_Text NVARCHAR(MAX) = NULL
)
AS
BEGIN

	SET NOCOUNT ON

    INSERT INTO [PackageDependents]
    (
        [Feed_Id],
        [Package_Name],
        [Group_Name],
        [Version_Text],
        [Dependent_Package_Name],
        [Dependent_Group_Name],
        [Dependent_Version_Text],
        [Notes_Text],
        [Dependent_Feed_Id],
        [Dependent_Url],
        [Created_Date]
    )
    SELECT [Feed_Id],
           [Package_Name],
           [Group_Name],
           [Version_Text],
           [Dependent_Package_Name],
           [Dependent_Group_Name],
           @New_Dependent_Version_Text,
           @Notes_Text,
           @New_Dependent_Feed_Id,
           [Dependent_Url],
           GETUTCDATE()
      FROM [PackageDependents] PD
     WHERE [Dependent_Feed_Id] = @Dependent_Feed_Id
       AND [Dependent_Group_Name] = @Dependent_Group_Name
       AND [Dependent_Package_Name] = @Dependent_Package_Name
       AND [Dependent_Version_Text] = @Dependent_Version_Text
       AND NOT EXISTS(SELECT *
                        FROM [PackageDependents] PD2
                       WHERE PD2.[Feed_Id] = PD.[Feed_Id]
                         AND PD2.[Group_Name] = PD.[Group_Name]
                         AND PD2.[Package_Name] = PD.[Package_Name]
                         AND PD2.[Version_Text] = PD.[Version_Text]
                         AND PD2.[Dependent_Feed_Id] = @New_Dependent_Feed_Id
                         AND PD2.[Dependent_Group_Name] = PD.[Dependent_Group_Name]
                         AND PD2.[Dependent_Package_Name] = PD.[Dependent_Package_Name]
                         AND PD2.[Dependent_Version_Text] = @New_Dependent_Version_Text)
END
GO

GRANT EXECUTE ON [PackageDependents_AddRepackageRecords] TO [ProGetUser_Role]
GO
